=====================
Creepy Computer Games
=====================

.. image:: cover.jpg

`Download the original book <https://drive.google.com/open?id=0Bxv0SsvibDMTRUl3SFRONGN0MFk>`__



.. toctree::
   :maxdepth: 1

   computer_nightmare/index
   the_number_wizard/index
   ghost_guzzler/index
   spiderwoman/index
   gravedigger/index
   mad_house/index
   ghost_maze/index
   seance/index

